@@ -13,7 +13,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from io import StringIO
 import fcntl
 import locale
 import os
@@ -22,11 +21,11 @@ import shutil
 import sys
 import tempfile
 import unittest
+from io import StringIO
 
 from tests.common import build_temp_workspace, temp_workspace
 
-from yamllint import cli
-from yamllint import config
+from yamllint import cli, config
 
 
 class RunContext:
@@ -38,13 +37,17 @@ class RunContext:
 
     def __enter__(self):
         self._raises_ctx.__enter__()
+        self.old_sys_stdout = sys.stdout
+        self.old_sys_stderr = sys.stderr
         sys.stdout = self.outstream = StringIO()
         sys.stderr = self.errstream = StringIO()
         return self
 
     def __exit__(self, *exc_info):
-        self.stdout, sys.stdout = self.outstream.getvalue(), sys.__stdout__
-        self.stderr, sys.stderr = self.errstream.getvalue(), sys.__stderr__
+        self.stdout = self.outstream.getvalue()
+        self.stderr = self.errstream.getvalue()
+        sys.stdout = self.old_sys_stdout
+        sys.stderr = self.old_sys_stderr
         return self._raises_ctx.__exit__(*exc_info)
 
     @property
@@ -57,9 +60,30 @@ def utf8_available():
     try:
         locale.setlocale(locale.LC_ALL, 'C.UTF-8')
         locale.setlocale(locale.LC_ALL, (None, None))
-        return True
     except locale.Error:  # pragma: no cover
         return False
+    else:
+        return True
+
+
+def setUpModule():
+    # yamllint uses these environment variables to find a config file.
+    env_vars_that_could_interfere = (
+        'YAMLLINT_CONFIG_FILE',
+        'XDG_CONFIG_HOME',
+        # These variables are used to determine where the user’s home
+        # directory is. See
+        # https://docs.python.org/3/library/os.path.html#os.path.expanduser
+        'HOME',
+        'USERPROFILE',
+        'HOMEPATH',
+        'HOMEDRIVE'
+    )
+    for name in env_vars_that_could_interfere:
+        try:
+            del os.environ[name]
+        except KeyError:
+            pass
 
 
 class CommandLineTestCase(unittest.TestCase):
@@ -116,8 +140,6 @@ class CommandLineTestCase(unittest.TestCase):
 
         shutil.rmtree(cls.wd)
 
-    @unittest.skipIf(not utf8_available() and sys.version_info < (3, 7),
-                     'UTF-8 paths not supported')
     def test_find_files_recursively(self):
         conf = config.YamlLintConfig('extends: default')
         self.assertEqual(
@@ -306,14 +328,13 @@ class CommandLineTestCase(unittest.TestCase):
             cli.run(('-c', f.name, os.path.join(self.wd, 'a.yaml')))
         self.assertEqual(ctx.returncode, 1)
 
-    @unittest.skipIf(os.environ.get('GITHUB_RUN_ID'), '$HOME not overridable')
     def test_run_with_user_global_config_file(self):
         home = os.path.join(self.wd, 'fake-home')
         dir = os.path.join(home, '.config', 'yamllint')
         os.makedirs(dir)
         config = os.path.join(dir, 'config')
 
-        self.addCleanup(os.environ.update, HOME=os.environ['HOME'])
+        self.addCleanup(os.environ.__delitem__, 'HOME')
         os.environ['HOME'] = home
 
         with open(config, 'w') as f:
