@@ -19,8 +19,7 @@ import os
 import platform
 import sys
 
-from yamllint import APP_DESCRIPTION, APP_NAME, APP_VERSION
-from yamllint import linter
+from yamllint import APP_DESCRIPTION, APP_NAME, APP_VERSION, linter
 from yamllint.config import YamlLintConfig, YamlLintConfigError
 from yamllint.linter import PROBLEM_LEVELS
 
@@ -28,7 +27,7 @@ from yamllint.linter import PROBLEM_LEVELS
 def find_files_recursively(items, conf):
     for item in items:
         if os.path.isdir(item):
-            for root, dirnames, filenames in os.walk(item):
+            for root, _dirnames, filenames in os.walk(item):
                 for f in filenames:
                     filepath = os.path.join(root, f)
                     if conf.is_yaml_file(filepath):
@@ -79,9 +78,9 @@ class Format:
 
     @staticmethod
     def github(problem, filename):
-        line = f'::{problem.level} file={format(filename)},' \
-               f'line={format(problem.line)},col={format(problem.column)}' \
-               f'::{format(problem.line)}:{format(problem.column)} '
+        line = f'::{problem.level} file={filename},' \
+               f'line={problem.line},col={problem.column}' \
+               f'::{problem.line}:{problem.column} '
         if problem.rule:
             line += f'[{problem.rule}] '
         line += problem.desc
